#include <Arduino.h>
#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>
#include <EEPROM.h>
#include <ESP8266HTTPClient.h>
#include "WEBset.h"                // Hier ist die HTML-Webseite als Array abgelegt
#include "TM1637Display.h"
#define LDRpin 14                  // Pin an dem Fotowiderstand angeschlossen ist
const int CLK = 13;                // Set the CLK pin connection to the display
const int DIO = 12;                // Set the DIO pin connection to the display
#define RTC_Wert 600e6             // 10min Schlafzyklus
IPAddress apIP(192, 168, 178, 1);  // IP-Adresse für Setup

int z = 0;                         // Aktuelle EEPROM-Adresse zum lesen
String nachricht = "";
String url = "";
TM1637Display display(CLK, DIO);   //set up the 4-Digit Display.
uint8_t data[] = { 0x0, 0x0, 0x0, 0x0 }; // Einzelne Digits ansteuern

char ssid[32] = "fhgdhfghd\0";
char passwort[64] = "gghdfgh\0";
int timout = 0;                    // Variable um Verbindungsversuch zu zehlen
ESP8266WebServer server;
EspClass ESPm;
HTTPClient http;
#include "Setup.h"                 // Programmteil mit Einstellen im AP-Mode

extern "C" {
#include "user_interface.h"
}

void setup()
{
  pinMode(1, OUTPUT);       // TX     Überprüfen ob Tx und Rx gebrückt sind
  pinMode(3, INPUT_PULLUP); // Rx
  digitalWrite(1, 1);
  delayMicroseconds(2);
  if (!digitalRead(3))goto weiter;

  digitalWrite(1, 0);
  delayMicroseconds(2);
  if (digitalRead(3))goto weiter;
  Einstellen();                      // TxD ist mit RxD verbunden-> Setupmodus (Setup.h)
weiter:

  Serial.begin(115200);
  Serial.println("Start");
  int ldr = LDR();                // Ladezeit des Kondensators messen
  if (ldr == 0)ldr = 1;           // Das Teilen gegen "0" vermeiden
  ldr = 5000 / ldr;               // Kehrwert bilden
  ldr = ldr * 7 / 300;            // Mazimele Helligkeit 300-> LED-Helligkeit 7
  if (ldr > 7)ldr = 7;            // Wenn doch mehr Licht kommt
  display.setBrightness(ldr + 1); // 0 ist aus, 8 ist maximum
   
  EEPROM.begin(250);              // EEPROM initialisieren 
  z = 0;                          // Einstellungen einlesen
  LeseEeprom(ssid, sizeof(ssid));
  LeseEeprom(passwort, sizeof(passwort));
  LeseEepromStr(&url, 100);
  LeseEepromStr(&nachricht, 100);
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, passwort);
  while (WiFi.status() != WL_CONNECTED) // Warte auf Verbindung
  {
    timout++;
    if  (timout > 60)                   // Wenn Anmeldung nicht möglich
    {
      data[3] = 0b10000000;             // Erste Punkt rechts
      display.setSegments(data, 4, 0);  // aufleuchten lassen
      ESPm.deepSleep(RTC_Wert, WAKE_RFCAL); // und schlafen gehen
      delay(100);
    }      // End timeout
    delay(200);
  }                                     // Verbunden
  Serial.begin(115200);
  http.begin(url);                      // Webseite aufrufen
  int httpCode = http.GET();            // Antwort des Servers einlesen
  if (httpCode > 0)
  {
    if (httpCode == HTTP_CODE_OK)       // Wenn Antwort OK
    {
      String payload = http.getString();//Webseite einlesen
      // Wenn '|' Zeichen entchalten dann vom Anfang bis '|' Zeichen einlesen
      // Sons alles einlesen  
      if (payload.indexOf('|')) payload = payload.substring(0, payload.indexOf('|'));
      Serial.println(payload);          // Seriell ausgeben
      display.showNumberDec(payload.toInt()); // Auf Siebensegmentanzeige ausgeben
    }
  } else {
    Serial.printf("[HTTP] GET... failed, error: %s\n", http.errorToString(httpCode).c_str());
    data[0] = 128 ;                     // Wenn Fehler beim laden der Webseite 
    data[1] = 128 ;                     // Dann alle vier Punkte leuchten lassen
    data[2] = 128 ;
    data[3] = 128 ;
    display.setSegments(data, 4, 0);
  }
  http.end();
  ESPm.deepSleep(RTC_Wert, WAKE_RFCAL); // für 10 Minuten einschlafen
  delay(100);
}

void loop()
{
  yield();
}

unsigned int LDR ()           // LDR-Wert einlesen
{
  unsigned int Licht = 0;
  pinMode(LDRpin, OUTPUT);
  digitalWrite(LDRpin, 1);    // Kondensator laden
  delay(1);                   // Zeit zum Laden
  pinMode(LDRpin, INPUT);     
  while (digitalRead(LDRpin)) //Entladezeit messen
  {
    Licht++;
    delayMicroseconds(5);     // in 5us Sritten
    if ((Licht > 5000) )return 5000; // Wenn zu lange dauert abbrechen
  }
  return Licht;
}
